@@ -24,7 +24,7 @@ class MonitoredClientSession(ClientSession):
         exemplar = get_request_id_exemplar()
         labels = {'method': method.upper(), 'url': str(yarl.URL(str_or_url).with_query({}))}
         labels |= extended_metrics_labels or {}
-        self._metrics.counter('http_client__requests', labels).inc(exemplar=exemplar)
+        self._metrics.counter('http_client__submitted_requests', labels).inc(exemplar=exemplar)
         with self._metrics.track('http_client__requests', labels, exemplar=exemplar) as tracker:
             try:
                 response = await super()._request(method, str_or_url, **kwargs)
